Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-11-23 22:13:03 +0000
committerStijn Buys <ingar@osirion.org>2008-11-23 22:13:03 +0000
commitd01664f17503d52d4be1c31e099065da0d38d7f3 (patch)
tree63f15840977a02bdeca925c16a80b3da93dae5d8 /src/model/model.h
parentac3663d05da4e236d02620ae98d5a7e6882bc802 (diff)
merged model classes into one file, classname cleanup, fx_particles
Diffstat (limited to 'src/model/model.h')
-rw-r--r--src/model/model.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/src/model/model.h b/src/model/model.h
index cb10386..5b52fde 100644
--- a/src/model/model.h
+++ b/src/model/model.h
@@ -12,16 +12,17 @@
#include <map>
#include "math/mathlib.h"
-#include "model/dock.h"
-#include "model/engine.h"
+#include "model/classes.h"
#include "model/fragment.h"
-#include "model/light.h"
-#include "model/flare.h"
/// classes representing 3D geometry
namespace model
{
+/// scaling factor when loading .map geometry
+const float SCALE = 1.0f / 1024.0f;
+const float LIGHTSCALE = 1.0f / 100.0f;
+
/// a 3D model contains a list of faces
class Model
{
@@ -41,8 +42,8 @@ public:
/// type definition for a lost of dockable locations
typedef std::list<Dock *> Docks;
- /// type definition for a list of model engines
- typedef std::list<Engine *> Engines;
+ /// type definition for a list of model particles
+ typedef std::list<Particles *> ParticleSystems;
/// create a model with a name
Model(std::string const & name);
@@ -87,9 +88,9 @@ public:
}
/// list of engines
- inline Engines & engines()
+ inline ParticleSystems & particles()
{
- return model_engines;
+ return model_particles;
}
/// maximum values of the bounding box
@@ -122,8 +123,8 @@ public:
/// add a light to the model
void add_light(Light *light);
- /// add an engine to the model
- void add_engine(Engine *engine);
+ /// add a particle system to the model
+ void add_particles(Particles *particles);
/// add a flare to the model
void add_flare(Flare *flare);
@@ -181,9 +182,9 @@ private:
FragmentGroup model_worldspawn;
Docks model_docks;
- Engines model_engines;
Flares model_flares;
Lights model_lights;
+ ParticleSystems model_particles;
};
}